@@ -41,7 +41,7 @@ class PWebResource(Resource):
         if 'fields' in content:
             self._meta['fields'] = content['fields'].keys()
         else:
-            self._meta['fields'] = None
+            self._meta['fields'] = self._meta.get('fields', None)
 
 
 class PWebCollection(Collection):
@@ -98,6 +98,23 @@ class Identity(PWebResource):
         return notification
 
 
+class AccountMember(PWebResource):
+    url_attribute_name = 'membership_details_url'
+    
+    def __init__(self, *args, **kwargs):
+        super(AccountMember, self).__init__(*args, **kwargs)
+
+        self._meta['fields'] = ['roles']
+
+    @property
+    def url(self):
+        return super(AccountMember, self).url or self._response.url
+    
+
+class AccountMembers(PWebCollection):
+    resource_class = AccountMember
+
+
 class Account(object):
     # Accounts can only be manipulated via ServiceAccounts
 
@@ -153,6 +170,9 @@ class ServiceAccount(PWebResource):
         if 'notifications_url' in self.resource_data:
             self.notifications = Notifications(url=self.notifications_url, session=self._session)
 
+        if 'add_member_url' in self.resource_data:
+            self.members = AccountMembers(url=self.add_member_url, session=self._session)
+
     def send_notification(self, body, **kwargs):
         kwargs['body'] = body
     
